auth

package
v0.0.0-...-8979337 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AgentFromContext

func AgentFromContext(ctx context.Context) *store.Agent

func FingerprintFromContext

func FingerprintFromContext(ctx context.Context) string

FingerprintFromContext returns the SSH key fingerprint stored during auth.

func PubKeyFromContext

func PubKeyFromContext(ctx context.Context) string

PubKeyFromContext returns the marshaled public key stored during auth.

func PublicKeyHandler

func PublicKeyHandler(s store.Store) func(ctx ssh.Context, key ssh.PublicKey) bool

PublicKeyHandler accepts all keys but only sets agent context for known ones. This allows unauthenticated users to connect and redeem invites.

func SetAgentInContext

func SetAgentInContext(ctx ssh.Context, agent *store.Agent)

SetAgentInContext stores the agent in a context that supports SetValue. This is used by tests and the PublicKeyHandler.

Types

This section is empty.

Jump to