Documentation
¶
Index ¶
- func AgentFromContext(ctx context.Context) *store.Agent
- func FingerprintFromContext(ctx context.Context) string
- func PubKeyFromContext(ctx context.Context) string
- func PublicKeyHandler(s store.Store) func(ctx ssh.Context, key ssh.PublicKey) bool
- func SetAgentInContext(ctx ssh.Context, agent *store.Agent)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FingerprintFromContext ¶
FingerprintFromContext returns the SSH key fingerprint stored during auth.
func PubKeyFromContext ¶
PubKeyFromContext returns the marshaled public key stored during auth.
func PublicKeyHandler ¶
PublicKeyHandler accepts all keys but only sets agent context for known ones. This allows unauthenticated users to connect and redeem invites.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.